****************
* This do file creates the tables in "Do Television and Radio Destroy Social Capital? Evidence from Indonesian Villages"
* using data from the PODES data
* July 2009
* Benjamin A. Olken
* It is to be used with Stata v. 9.2 or later
*****************

version 9.2


local villagecontrols = 	"mean_adulted_w00 log_adu*p_w90 log_ham*s_w05 pop_agric_w90 sch*s_w90 num_mo*_w90 num_mu*_w90 ot*es_w90 sp*s_w90 arts_w90 soc_w90 youth_w90 eth_frag_w00 rel_frag_w00 pov_rate_w05 coastal_w90 elevation city_dist_w05 city_t*e_w05 c_cit*th_km asp*4*"  


capture log close
log using 080311tvpanelanalysis, t replace

clear
set mem 500m
set matsize 5000

use podesdata,clear


/* Table of summary stats*/
g str40 varname = ""
g outinfo = .
local numvar = 1
g totany_w03 = totany if wave == 2003
g totany_w90 = totany if wave == 1990
g tvchannels_w03 = tvchannels if wave == 2003
bys kabid: egen meannumchannels = mean(tvchannels) if wave == 2003
g tvchannelsdemeaned = tvchannels - meannumchannels  if wave == 2003



foreach X of var tvchannels_w03 tvchannelsdemeaned  totany_w03 totany_w90 {
	
	local numstd = `numvar' + 1
	summ `X' 
	replace outinfo = r(mean) in `numvar'
	replace outinfo = -1 * r(sd) in `numstd'
	replace varname = "`X'" in `numvar'
	local numvar = `numvar' + 2
}
local numvar = `numvar' - 1
outsheet varname outinfo using podessumstats.out in 1/`numvar', replace


use podesdata,clear





*****
* Figure 3
*****
for any A B C D E F G H I J K \ any TVRI RCTI SCTV ANTV INDOSIAR METRO TV7 TRANS TPI LATIVI GLOBAL: fanreg TV_Y tvmaxtveloss5050powerX, title("Y") saving ("ChanY", replace) bw(3) cluster(kecnum) max(1) min(0) maxminon reps(50) ytitle(" ") 

graph combine ChanTVRI.gph ChanRCTI.gph ChanSCTV.gph ChanINDOSIAR.gph ChanMETRO.gph ChanANTV.gph ChanTV7.gph ChanTRANS.gph ChanTPI.gph ChanLATIVI.gph ChanGLOBAL.gph, row(4) xsize(7) ysize(10) ycommon xcommon
graph export Figure3.eps, replace


******
* test first stage power
******

areg tvchannels eloss floss `villagecontrols' if wavenum == 2003, absorb(kabid) cluster(kecnum)
testparm eloss
local fval = r(F)
local depvar = e(depvar)
qui summ `depvar' if e(sample) 
outreg using table10_podes, 3aster coefastr se replace title("`depVar'") adds("Mean dep. var",r(mean),"F stat",`fval') ctitle("PODES sample")

******
* Run regressions
*******

xtivreg2 totany tvchannels  kabiddummy* , fe i(kecnum) cluster(kecnum) 
local depvar = e(depvar)
qui summ `depvar' if e(sample) 
outreg tvchannels using table11_podes, 3aster coefastr se adds("Mean dep. var",r(mean)) ctitle("OLS-Panel") replace title("PODES panel `depVar'")

xtivreg2 totany (tvchannels = elosspanel) flosspanel kabiddummy* , fe i(kecnum) cluster(kecnum) ffirst
matrix temp = e(first)
scalar tempF = temp[3,1]
local tempFLocal = tempF
local depvar = e(depvar)
qui summ `depvar' if e(sample) 
outreg tvchannels flosspanel using table11_podes, 3aster coefastr se append adds("Mean dep. var",r(mean),"First stage F",`tempFLocal') ctitle("IV-panel")


